@@ -1,6 +1,6 @@
 ##
 ## R package dynsurv by Wenjie Wang, Ming-Hui Chen, Xiaojing Wang, and Jun Yan
-## Copyright (C) 2011-2023
+## Copyright (C) 2011-2024
 ##
 ## This file is part of the R package dynsurv.
 ##
@@ -29,8 +29,9 @@
 ##'     data using estimating equations.
 ##' }
 ##'
-##' @docType package
+##' @useDynLib dynsurv
+##'
 ##' @name dynsurv
 ##' @aliases dynsurv-package
-##' @useDynLib dynsurv
-NULL
+##' @keywords internal
+"_PACKAGE"
